
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/sauge/code/progress/ezine34/RCS/ReadDirectory.p,v 1.1 2003/07/21 08:23:05 sauge Exp sauge $" NO-UNDO.

/* Given a directory, list the files in the directory */

DEF INPUT PARAMETER cDirectoryName   AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER cDirectoryList  AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER cFileList       AS CHARACTER NO-UNDO.

DEF VAR cDelimiter AS CHARACTER NO-UNDO.
DEF VAR cRawList   AS CHARACTER NO-UNDO.
DEF VAR cLine      AS CHARACTER FORMAT "x(10000)" NO-UNDO.

DEF VAR cCurrentFileName  AS CHARACTER NO-UNDO.
DEF VAR iCurrentFile      AS INTEGER NO-UNDO.
DEF VAR iMaxFile          AS INTEGER NO-UNDO.

ASSIGN cDelimiter = CHR(250).  /* Something unlikely in a file name */

/* Pull in the list of files for the given directory */

IF OPSYS = "WIN32" THEN
  INPUT THRU "dir /b" VALUE(cDirectoryName).
ELSE 
  INPUT THRU ls VALUE(cDirectoryName).

  REPEAT:

    IMPORT UNFORMATTED cLine.

    ASSIGN cRawList = cRawList + cLine + cDelimiter.

  END.

INPUT CLOSE.

/* Figure out what the files are and put into the appropriate list */

ASSIGN iMaxFile = NUM-ENTRIES(cRawList, cDelimiter).
ASSIGN iMaxFile = iMaxFile - 1.  /* Drop the final delimiter */

DO iCurrentFile = 1 TO iMaxFile:

  ASSIGN cCurrentFileName = ENTRY (iCurrentFile, cRawList, cDelimiter).

  FILE-INFO:FILE-NAME = cDirectoryName + "/" + cCurrentFileName.

  IF FILE-INFO:FILE-TYPE BEGINS "D" OR FILE-INFO:FILE-TYPE BEGINS "L" THEN 
    ASSIGN cDirectoryList = cDirectoryList + cCurrentFileName + cDelimiter.
  ELSE
    ASSIGN cFileList = cFileList + cCurrentFileName + cDelimiter.

END. /* DO iCurrentFile = 1 TO iMaxFile: */

/* Knock off the final delimiters */

IF LENGTH (cFileList) > 0 THEN 
  ASSIGN cFileList = SUBSTRING(cFileList, 1, LENGTH(cFileList) - 1).

IF LENGTH (cDirectoryList) > 0 THEN 
  ASSIGN cDirectoryList = SUBSTRING(cDirectoryList, 1, LENGTH(cDirectoryList) -  1).

